package com.ruixuan.isc.service.impl;


import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.kuaishou.merchant.open.api.KsMerchantApiException;
import com.kuaishou.merchant.open.api.client.AccessTokenKsMerchantClient;
import com.kuaishou.merchant.open.api.common.utils.GsonUtils;
import com.kuaishou.merchant.open.api.request.distribution.OpenDistributionInvestmentActivityInvalidItemListRequest;
import com.kuaishou.merchant.open.api.request.distribution.OpenDistributionInvestmentActivityItemDetailRequest;
import com.kuaishou.merchant.open.api.request.distribution.OpenDistributionPublicCategoryListRequest;
import com.kuaishou.merchant.open.api.response.distribution.OpenDistributionInvestmentActivityInvalidItemListResponse;
import com.kuaishou.merchant.open.api.response.distribution.OpenDistributionInvestmentActivityItemDetailResponse;
import com.kuaishou.merchant.open.api.response.distribution.OpenDistributionPublicCategoryListResponse;
import com.ruixuan.common.utils.Check;
import com.ruixuan.common.utils.KsHttpUtils;
import com.ruixuan.isc.constants.KuaiShouConstants;
import com.ruixuan.isc.entity.KuaishouItemList;
import com.ruixuan.isc.entity.KuaishouItemCategory;
import com.ruixuan.isc.mapper.KuaishouItemListMapper;
import com.ruixuan.isc.mapper.SupplyChainMapper;
import com.ruixuan.isc.service.IKuaishouItemListService;
import com.sun.org.apache.xml.internal.security.c14n.helper.C14nHelper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;


/**
 * 【请填写功能名称】Service业务层处理
 *
 * @author ruoyi
 * @date 2023-02-03
 */
@Service
@Slf4j
public class KuaishouItemListServiceImpl implements IKuaishouItemListService {
    @Autowired
    private KuaishouItemListMapper kuaishouItemListMapper;


    @Override
    public List<KuaishouItemList> getItemList(Map<String, Object> requestMap) {
        return kuaishouItemListMapper.getItemList(requestMap);
    }

    @Override
    public JSONObject getItemDetail(Long activityId, Long itemId, String accessToken) throws Exception {
        JSONObject returnJson = new JSONObject();
        AccessTokenKsMerchantClient client = new AccessTokenKsMerchantClient(KuaiShouConstants.KFX_URL, KuaiShouConstants.APP_KEY, KuaiShouConstants.SIGN_SECRET);
        OpenDistributionInvestmentActivityItemDetailRequest request = new OpenDistributionInvestmentActivityItemDetailRequest();
        request.setAccessToken(accessToken);
        request.setApiMethodVersion(1L);
        request.setActivityId(activityId);
        List<Long> item = new ArrayList<>();
        item.add(itemId);
        request.setItemId(item);
        OpenDistributionInvestmentActivityItemDetailResponse response = client.execute(request);
        JSONObject json = JSONObject.parseObject(GsonUtils.toJSON(response));
        log.info("获取信息返回数据:{}", json);
        if (Check.isNull(json)) {
            throw new Exception("获取商品信息出错，请重新提交");
        }
        Integer code = json.getInteger("code");
        Integer subCode = json.getInteger("sub_code");
        if (code == 1 && subCode == 1) {
            JSONArray data = json.getJSONArray("data");
            if (Check.isNull(data)) {
                returnJson.put("code", -1);
                returnJson.put("message", "数据查询失败");
                return returnJson;
            }
            JSONObject itemJson = data.getJSONObject(0);
            Long categoryId = itemJson.getLong("categoryId");
            String categoryInfo = getCategoryInfo(categoryId);
            if (!Check.isNull(categoryInfo)) {
                itemJson.put("categoryName", categoryInfo);
            }
            itemJson.put("detailUrl", "https://app.kwaixiaodian.com/merchant/shop/detail?id=" + itemId);

            returnJson.put("judgeStatus", 1);
            returnJson.put("itemJson", itemJson);
            returnJson.put("code", 0);
            returnJson.put("message", "查询成功");


        } else if (code == 807000 && (subCode == 24101 || subCode == 24214)) { // 商品下线
            returnJson = getInvaliItemDetail(activityId, itemId, accessToken);
        } else {
            returnJson.put("code", -1);
            returnJson.put("message", "数据查询失败");
        }
        return returnJson;
    }

    private String getCategoryInfo(Long categoryId) {
        if (Check.isNull(categoryId)) {
            return null;
        }
        StringBuffer stringBuffer = new StringBuffer();

        KuaishouItemCategory category = kuaishouItemListMapper.getCategoryInfo(categoryId);
        KuaishouItemCategory secondCategory = new KuaishouItemCategory();
        KuaishouItemCategory thirdCategory = new KuaishouItemCategory();
        if (category.getCategorySort() == 1) {

            stringBuffer.append(category.getCategoryName());
        } else if (category.getCategorySort() == 2) {
            secondCategory = kuaishouItemListMapper.getCategoryInfo(category.getParentId());
            stringBuffer.append(secondCategory.getCategoryName()).append(">").append(category.getCategoryName());
        } else if (category.getCategorySort() == 3) {
            secondCategory = kuaishouItemListMapper.getCategoryInfo(category.getParentId());
            thirdCategory = kuaishouItemListMapper.getCategoryInfo(secondCategory.getParentId());
            stringBuffer.append(thirdCategory.getCategoryName()).append(">").append(secondCategory.getCategoryName()).append(">").append(category.getCategoryName());
        }

        return stringBuffer.toString();


    }

    @Override
    public KuaishouItemList getItemInfoByItemId(Long itemId) {
        return kuaishouItemListMapper.getItemInfoByItemId(itemId);
    }

    @Override
    public void insertItem(KuaishouItemList kuaishouItemList) {
        kuaishouItemListMapper.insertItem(kuaishouItemList);
    }

    @Override
    public int updateKuaishouItemList(KuaishouItemList kuaishouItemList) {
        return kuaishouItemListMapper.updateKuaishouItemList(kuaishouItemList);
    }

    @Override
    public int deleteKuaishouItemListByItemIds(Long[] itemIds) {
        return kuaishouItemListMapper.deleteKuaishouItemListByItemIds(itemIds);
    }

    @Override
    public int addCategoryId() throws KsMerchantApiException {
        String url = "https://openapi.kwaixiaodian.com";
        String appKey = "ks665688320292774929";
        String signSecret = "8e21f5bc03b6d2dc63e6256225dac00b";
        String accessToken = "ChFvYXV0aC5hY2Nlc3NUb2tlbhJg5CLuL6ttwj9MiWcCHbVN4sRko6KKjKrjzmWJ3GBpR_s7IKevDH5orkC2xKtmrkGESX3VkZVGTFpjw-hqSOHPtJmMfj0QH-_bKLqdYO0t56zqyJr_pTibE1rR6tFUgaAaGhINVY3cQVhC4YDnv5YNyfZ0IKwiIEtqPp9U48e9lE_g3P9Th_KB-cb9VF1e0xlABypm9xdqKAUwAQ";
        AccessTokenKsMerchantClient client = new AccessTokenKsMerchantClient(url, appKey, signSecret);
        OpenDistributionPublicCategoryListRequest request = new OpenDistributionPublicCategoryListRequest();
        request.setAccessToken(accessToken);
        request.setApiMethodVersion(1L);
        OpenDistributionPublicCategoryListResponse response = client.execute(request);
        JSONObject jsonObject = JSONObject.parseObject(GsonUtils.toJSON(response));
        JSONArray data = jsonObject.getJSONArray("data");
        List<KuaishouItemCategory> adds = new ArrayList<>();

        for (int i = 0; i < data.size(); i++) {
            JSONObject first = data.getJSONObject(i);
            KuaishouItemCategory firstCategory = new KuaishouItemCategory();
            firstCategory.setCategoryId(first.getLong("categoryId"));
            firstCategory.setCategoryName(first.getString("categoryName"));
            firstCategory.setCategorySort(1);
            firstCategory.setParentId(1L);
            Long firstCategoryId = first.getLong("categoryId");
            adds.add(firstCategory);
            JSONArray secondChildCategory = first.getJSONArray("childCategory");
            if (!Check.isNull(secondChildCategory)) {
                for (int j = 0; j < secondChildCategory.size(); j++) {
                    JSONObject second = secondChildCategory.getJSONObject(j);
                    KuaishouItemCategory secondCategory = new KuaishouItemCategory();
                    secondCategory.setParentId(firstCategoryId);
                    secondCategory.setCategoryId(second.getLong("categoryId"));
                    secondCategory.setCategoryName(second.getString("categoryName"));
                    secondCategory.setCategorySort(2);
                    Long secondCategoryId = second.getLong("categoryId");
                    adds.add(secondCategory);
                    JSONArray thirdChildCategory = second.getJSONArray("childCategory");
                    if (!Check.isNull(thirdChildCategory)) {
                        for (int k = 0; k < thirdChildCategory.size(); k++) {
                            JSONObject third = thirdChildCategory.getJSONObject(k);
                            KuaishouItemCategory thirdCategory = new KuaishouItemCategory();
                            thirdCategory.setParentId(secondCategoryId);
                            thirdCategory.setCategoryId(third.getLong("categoryId"));
                            thirdCategory.setCategoryName(third.getString("categoryName"));
                            thirdCategory.setCategorySort(3);
                            adds.add(thirdCategory);
                        }
                    }
                }

            }


        }
        kuaishouItemListMapper.batchCategory(adds);

        System.err.println(jsonObject);


        return 0;
    }

    @Autowired
    private SupplyChainMapper supplyChainMapper;

    private JSONObject getInvaliItemDetail(Long activityId, Long itemId, String accessToken) throws Exception {
        JSONObject returnJson = new JSONObject();
        String cookie = supplyChainMapper.getCookie();
        Map<String, Object> params = new HashMap<>();
        params.put("limit", 20);
        params.put("offset", 0);
        params.put("activityId", activityId);
        params.put("itemId", itemId);

        Map<String, String> headers = new HashMap<>();
        headers.put("Cookie", cookie);
        String resultStr = KsHttpUtils.KuaiShouttpGetRequest("https://cps.kwaixiaodian.com/distribute/pc/investment/activity/item/list", params, headers);
        JSONObject result = JSONObject.parseObject(resultStr);
        if (Check.isNull(result)) {
            log.error("快分销招商商品数据返回为空");
            returnJson.put("code", -1);
            returnJson.put("message", "获取商品信息为空");
            return returnJson;
        }
        Integer code = result.getInteger("result");
        if (code != 1) {
            log.info("快分销招商商品数据返回异常：", resultStr);
            //   sendMessageService.sendMessage("113dee46c7df464da78c07a985e92cd1", "快手供应链cookie失效，请及时更新。媒体返回信息：" + resultStr);
            returnJson.put("code", -1);
            returnJson.put("message", "增加快手商品信息抓取失败，请联系技术人员");
            return returnJson;
        }
        JSONArray dataArray = result.getJSONArray("data");
        if (Check.isNull(dataArray)) {
            log.error("快分销招商商品数据返回为data数据为空");
            returnJson.put("code", -1);
            returnJson.put("message", "快分销招商商品数据返回为data数据为空");
            return returnJson;
        }
       JSONObject itemJson = dataArray.getJSONObject(0);
        itemJson.put("detailUrl", "https://app.kwaixiaodian.com/merchant/shop/detail?id=" + itemId);
        returnJson.put("judgeStatus", 2);
        returnJson.put("itemJson", itemJson);
        returnJson.put("code", 0);
        returnJson.put("message", "查询成功");

        return returnJson;
    }

}

